@@ -52,12 +52,18 @@ namespace Pinta.Core
 		protected ToolBarDropDownButton antialiasing_button;
 		private ToolBarItem aaOn, aaOff;
 		protected ToolBarDropDownButton alphablending_button;
+		private ToolBarItem abOn, abOff;
 		public event MouseHandler MouseMoved;
 		public event MouseHandler MousePressed;
 		public event MouseHandler MouseReleased;
 
+        public Cursor CurrentCursor { get; private set; }
+
 		protected BaseTool ()
 		{
+            CurrentCursor = DefaultCursor;
+
+            PintaCore.Workspace.ActiveDocumentChanged += Workspace_ActiveDocumentChanged;
 		}
 
 		static BaseTool ()
@@ -87,33 +93,37 @@ namespace Pinta.Core
 		{
 			get
 			{
-				if (antialiasing_button == null)
-				{
-					return false;
-				}
-				else
-				{
-					return ShowAntialiasingButton && (bool)antialiasing_button.SelectedItem.Tag;
-				}
+                return (antialiasing_button != null) &&
+                        ShowAntialiasingButton &&
+                        (bool)antialiasing_button.SelectedItem.Tag;
 			}
 
 			set
 			{
-				if (ShowAntialiasingButton && antialiasing_button != null)
-				{
-					if (value)
-					{
-						antialiasing_button.SelectedItem = aaOn;
-					}
-					else
-					{
-						antialiasing_button.SelectedItem = aaOff;
-					}
-				}
+			    if (!ShowAntialiasingButton || antialiasing_button == null)
+                    return;
+
+			    antialiasing_button.SelectedItem = value ? aaOn : aaOff;
+			}
+		}
+
+		public virtual bool UseAlphaBlending
+		{
+			get
+			{
+				return alphablending_button != null &&
+					   ShowAlphaBlendingButton &&
+					   (bool)alphablending_button.SelectedItem.Tag;
+			}
+			set
+			{
+				if (!ShowAlphaBlendingButton || alphablending_button == null)
+					return;
+
+				alphablending_button.SelectedItem = value ? abOn : abOff;
 			}
 		}
 
-		public virtual bool UseAlphaBlending { get { return ShowAlphaBlendingButton && (bool)alphablending_button.SelectedItem.Tag; } }
 		public virtual int Priority { get { return 75; } }
 
 		public virtual bool CursorChangesOnZoom { get { return false; } }
@@ -301,15 +311,11 @@ namespace Pinta.Core
 
 		protected virtual void OnActivated ()
 		{
-			PintaCore.Workspace.CanvasSizeChanged += new EventHandler(Workspace_CanvasSizeChanged);
-
 			SetCursor (DefaultCursor);
 		}
 
 		protected virtual void OnDeactivated(BaseTool newTool)
 		{
-			PintaCore.Workspace.CanvasSizeChanged -= new EventHandler(Workspace_CanvasSizeChanged);
-
 			SetCursor (null);
 		}
 
@@ -333,7 +339,10 @@ namespace Pinta.Core
 		
 		public void SetCursor (Gdk.Cursor cursor)
 		{
-			PintaCore.Chrome.Canvas.GdkWindow.Cursor = cursor;
+            CurrentCursor = cursor;
+
+            if (PintaCore.Workspace.HasOpenDocuments && PintaCore.Workspace.ActiveWorkspace.Canvas.GdkWindow != null)
+			    PintaCore.Workspace.ActiveWorkspace.Canvas.GdkWindow.Cursor = cursor;
 		}
 
 		/// <summary>
@@ -433,8 +442,8 @@ namespace Pinta.Core
 
 			alphablending_button = new ToolBarDropDownButton ();
 
-			alphablending_button.AddItem (Catalog.GetString ("Normal Blending"), "Toolbar.BlendingEnabledIcon.png", true);
-			alphablending_button.AddItem (Catalog.GetString ("Overwrite"), "Toolbar.BlendingOverwriteIcon.png", false);
+			abOn = alphablending_button.AddItem (Catalog.GetString ("Normal Blending"), "Toolbar.BlendingEnabledIcon.png", true);
+			abOff = alphablending_button.AddItem (Catalog.GetString ("Overwrite"), "Toolbar.BlendingOverwriteIcon.png", false);
 
 			tb.AppendItem (alphablending_button);
 		}
@@ -454,9 +463,10 @@ namespace Pinta.Core
 			tb.AppendItem (antialiasing_button);
 		}
 
-		private void Workspace_CanvasSizeChanged(object sender, EventArgs e)
+		private void Workspace_ActiveDocumentChanged (object sender, EventArgs e)
 		{
-			SetCursor (DefaultCursor);
+            if (PintaCore.Tools.CurrentTool == this)
+			    SetCursor (DefaultCursor);
 		}
 		#endregion
 	}
