@@ -39,27 +39,58 @@ namespace Pinta.Core
 		public List<List<IntPoint>> SelectionPolygons = new List<List<IntPoint>>();
 		public Clipper SelectionClipper = new Clipper();
 
-		public PointD selOrigin;
-		public PointD selEnd;
+		public PointD Origin;
+		public PointD End;
 
-		public Path SelectionPath
+		private bool _visible = true;
+		public bool Visible
 		{
-			get { return selection_path; }
+			get { return _visible; }
 			set
 			{
-				if (selection_path == value)
-					return;
+				_visible = value;
 
-                if (selection_path != null)
-                    selection_path.Dispose ();
-
-				selection_path = value;
+				// Notify any listeners.
+				if (SelectionModified != null)
+					SelectionModified.Invoke(this, EventArgs.Empty);
 			}
 		}
 
-		public void Clip (Context g)
+		public Path SelectionPath
 		{
-			g.AppendPath (selection_path);
+		    get
+		    {
+		        if (selection_path == null)
+		        {
+		            using (var g = new Context (PintaCore.Layers.CurrentLayer.Surface))
+		                selection_path = g.CreatePolygonPath (ConvertToPolygonSet (SelectionPolygons));
+		        }
+
+                return selection_path;
+		    }
+		}
+
+	    public event EventHandler SelectionModified;
+
+        /// <summary>
+        /// Indicate that the selection has changed.
+        /// </summary>
+        public void MarkDirty()
+        {
+            if (selection_path != null)
+            {
+                selection_path.Dispose ();
+                selection_path = null;
+            }
+
+            // Notify any listeners.
+            if (SelectionModified != null)
+                SelectionModified.Invoke(this, EventArgs.Empty);
+        }
+
+        public void Clip (Context g)
+		{
+			g.AppendPath (SelectionPath);
 			g.FillRule = FillRule.EvenOdd;
 			g.Clip ();
 		}
@@ -70,7 +101,7 @@ namespace Pinta.Core
 			g.Translate (0.5, 0.5);
 			g.Scale (scale, scale);
 			
-			g.AppendPath (selection_path);
+			g.AppendPath (SelectionPath);
 			
 			if (fillSelection)
 			{
@@ -94,25 +125,18 @@ namespace Pinta.Core
 		}
 
 		/// <summary>
-		/// Make a complete copy of the Selection.
+		/// Makes a copy of the Selection.
 		/// </summary>
-		/// <returns>A copy of this Selection (as a DocumentSelection object).</returns>
 		public DocumentSelection Clone()
 		{
-			DocumentSelection clonedSelection = new DocumentSelection();
-
-			if (selection_path != null)
-			{
-				clonedSelection.selection_path = selection_path.Clone();
-			}
-
-			clonedSelection.SelectionPolygons = SelectionPolygons.ToList();
-			clonedSelection.SelectionClipper = new Clipper();
-
-			clonedSelection.selOrigin = new PointD(selOrigin.X, selOrigin.Y);
-			clonedSelection.selEnd = new PointD(selEnd.X, selEnd.Y);
-
-			return clonedSelection;
+		    return new DocumentSelection
+		    {
+		        SelectionPolygons = SelectionPolygons.ToList (),
+		        SelectionClipper = new Clipper (),
+		        Origin = new PointD (Origin.X, Origin.Y),
+		        End = new PointD (End.X, End.Y),
+				_visible = this._visible
+		    };
 		}
 
 		/// <summary>
@@ -169,39 +193,46 @@ namespace Pinta.Core
 			return resultingPolygonSet;
 		}
 
-		public static List<List<IntPoint>> Transform (List<List<IntPoint>> selection, Matrix transform)
-		{
-			List<List<IntPoint>> newPolygons = new List<List<IntPoint>> ();
-			
-			foreach (List<IntPoint> ipL in selection) {
-				List<IntPoint> newPolygon = new List<IntPoint> ();
-				
-				foreach (IntPoint ip in ipL) {
-					double x = ip.X;
-					double y = ip.Y;
-					transform.TransformPoint (ref x, ref y);
-					newPolygon.Add (new IntPoint ((long)x, (long)y));
-				}
-				
-				newPolygons.Add (newPolygon);
-			}
-
-			return newPolygons;
-		}
-
 		/// <summary>
-		/// Create an elliptical Selection from a bounding Rectangle.
-		/// </summary>
-		/// <param name="selectionSurface">The selection surface to use for calculating the elliptical Path.</param>
-		/// <param name="r">The bounding Rectangle surrounding the ellipse.</param>
-		public void CreateEllipseSelection(Surface selectionSurface, Rectangle r)
+        /// Return a transformed copy of the selection.
+        /// </summary>
+        public DocumentSelection Transform (Matrix transform)
+        {
+            var newPolygons = new List<List<IntPoint>> ();
+
+            foreach (List<IntPoint> ipL in SelectionPolygons) {
+                List<IntPoint> newPolygon = new List<IntPoint> ();
+
+                foreach (IntPoint ip in ipL) {
+                    double x = ip.X;
+                    double y = ip.Y;
+                    transform.TransformPoint (ref x, ref y);
+                    newPolygon.Add (new IntPoint ((long)x, (long)y));
+                }
+
+                newPolygons.Add (newPolygon);
+            }
+
+            var origin = Origin;
+            var end = End;
+            transform.TransformPoint (ref origin);
+            transform.TransformPoint (ref end);
+
+            return new DocumentSelection {
+                SelectionPolygons = newPolygons,
+                SelectionClipper = new Clipper (),
+                Origin = origin,
+                End = end,
+                _visible = this._visible
+            };
+        }
+
+        /// <summary>
+        /// Create an elliptical Selection from a bounding Rectangle.
+        /// </summary>
+        /// <param name="r">The bounding Rectangle surrounding the ellipse.</param>
+        public void CreateEllipseSelection(Rectangle r)
 		{
-			using (Context g = new Context(selectionSurface))
-			{
-				SelectionPath = g.CreateEllipsePath(r);
-			}
-
-
 			//These values were calculated in the static CreateEllipsePath method
 			//in Pinta.Core.CairoExtensions, so they were used here as well.
 			double rx = r.Width / 2; //1/2 of the bounding Rectangle Width.
@@ -262,6 +293,7 @@ namespace Pinta.Core
 
 			//Add the newly calculated elliptical Polygon.
 			SelectionPolygons.Add(newPolygon);
+            MarkDirty ();
 		}
 
 		/// <summary>
@@ -277,7 +309,7 @@ namespace Pinta.Core
 		/// <param name="x3">Ending point X (included in the returned Point(s)).</param>
 		/// <param name="y3">Ending point Y (included in the returned Point(s)).</param>
 		/// <returns></returns>
-		List<IntPoint> CalculateCurvePoints(double tInterval, double x0, double y0, double x1, double y1, double x2, double y2, double x3, double y3)
+		private static List<IntPoint> CalculateCurvePoints(double tInterval, double x0, double y0, double x1, double y1, double x2, double y2, double x3, double y3)
 		{
 			//Create a new partial Polygon to store the calculated Points.
 			List<IntPoint> calculatedPoints = new List<IntPoint>((int)(1d / tInterval));
@@ -332,19 +364,16 @@ namespace Pinta.Core
 		/// <summary>
 		/// Create a rectangular Selection from a Rectangle.
 		/// </summary>
-		/// <param name="selectionSurface">The selection surface to use for calculating the rectangular Path.</param>
 		/// <param name="r">The Rectangle.</param>
-		public void CreateRectangleSelection(Surface selectionSurface, Rectangle r)
+		public void CreateRectangleSelection(Rectangle r)
 		{
-			using (Context g = new Context(selectionSurface))
-			{
-				SelectionPath = g.CreateRectanglePath(r);
-			}
-
-			//Clear the Selection Polygons collection to start from a clean slate.
 			SelectionPolygons.Clear();
-
 			SelectionPolygons.Add (CreateRectanglePolygon (r));
+
+		    Origin = new PointD (r.X, r.Y);
+		    End = new PointD (r.GetRight (), r.GetBottom ());
+
+            MarkDirty ();
 		}
 
 		/// <summary>
@@ -371,27 +400,10 @@ namespace Pinta.Core
 			SelectionClipper.Clear ();
 
 			SelectionPolygons = resultingPolygons;
-			using (Context g = new Context (surface)) {
-				SelectionPath = g.CreatePolygonPath (ConvertToPolygonSet (resultingPolygons));
-			}
+            MarkDirty ();
 		}
 
-		/// <summary>
-		/// Reset (clear) the Selection.
-		/// </summary>
-		/// <param name="selectionSurface"></param>
-		/// <param name="imageSize"></param>
-		public void ResetSelection(Surface selectionSurface, Gdk.Size imageSize)
-		{
-			using (Cairo.Context g = new Cairo.Context(selectionSurface))
-			{
-				SelectionPath = g.CreateRectanglePath(new Rectangle(0, 0, imageSize.Width, imageSize.Height));
-			}
-
-			SelectionPolygons.Clear();
-		}
-
-		private List<IntPoint> CreateRectanglePolygon (Rectangle r)
+		private static List<IntPoint> CreateRectanglePolygon (Rectangle r)
 		{
 			// The 4 corners of the Rectangle.
 			int corner1X = (int)Math.Round(r.X);
@@ -419,5 +431,16 @@ namespace Pinta.Core
             if (selection_path != null)
                 selection_path.Dispose ();
         }
+
+        /// <summary>
+        /// Resets the selection.
+        /// </summary>
+        public void Clear ()
+        {
+            SelectionPolygons.Clear ();
+            Origin = new PointD(0, 0);
+            End = new PointD(0, 0);
+            MarkDirty ();
+        }
     }
 }
