@@ -153,6 +153,27 @@ namespace Pinta.Core
 			return dirty;
 		}
 
+        public static Rectangle FillRectangle (this Context g, Rectangle r, Pattern pattern, PointD patternOffset)
+        {
+            g.Save ();
+
+            g.MoveTo (r.X, r.Y);
+            g.LineTo (r.X + r.Width, r.Y);
+            g.LineTo (r.X + r.Width, r.Y + r.Height);
+            g.LineTo (r.X, r.Y + r.Height);
+            g.LineTo (r.X, r.Y);
+
+            pattern.Matrix.Translate (-patternOffset.X, -patternOffset.Y);
+            g.SetSource (pattern);
+
+            Rectangle dirty = g.FixedStrokeExtents ();
+            g.Fill ();
+
+            g.Restore ();
+
+            return dirty;
+        }
+
 		public static Rectangle DrawPolygonal (this Context g, PointD[] points, Color color)
 		{
 			g.Save ();
@@ -780,7 +801,7 @@ namespace Pinta.Core
 
 				for (int i = 0; i < len; i++) {
 					if (dstPtr->A != 0)
-						*dstPtr = (ColorBgra.FromBgra (dstPtr->R, dstPtr->G, dstPtr->B, dstPtr->A));
+						*dstPtr = (ColorBgra.FromBgra ((byte)(dstPtr->R * 255 / dstPtr->A), (byte)(dstPtr->G * 255 / dstPtr->A), (byte)(dstPtr->B * 255 / dstPtr->A), dstPtr->A));
 					dstPtr++;
 				}
 
@@ -971,27 +992,39 @@ namespace Pinta.Core
 			}
 		}
 
-		public static Gdk.Rectangle GetBounds (this Path path)
-		{
-			Rectangle rect;
+        public static void Clear (this Context g, Rectangle roi)
+        {
+            g.Save ();
+            g.Rectangle (roi.X, roi.Y, roi.Width, roi.Height);
+            g.Clip ();
+            g.Operator = Operator.Clear;
+            g.Paint ();
+            g.Restore ();
+        }
 
-			using (Context g = new Context (PintaCore.Layers.CurrentLayer.Surface)) {
-				g.AppendPath (path);
+        [DllImport(CairoLib, CallingConvention = CallingConvention.Cdecl)]
+        private static extern void cairo_path_extents(IntPtr cr, out double x1, out double y1, out double x2, out double y2);
 
-				// We don't want the bounding box to include a stroke width 
-				// of 1, but setting it to 0 returns an empty rectangle.  Set
-				// it to a sufficiently small width and rounding takes care of it
-				g.LineWidth = .01;
-				rect = g.FixedStrokeExtents ();
-			}
+        public static Gdk.Rectangle GetBounds(this Path path)
+        {
+            Rectangle rect;
 
-			int x = (int)Math.Round (rect.X);
-			int y = (int)Math.Round (rect.Y);
-			int w = (int)Math.Round (rect.Width);
-			int h = (int)Math.Round (rect.Height);
+            using (Context g = new Context(PintaCore.Layers.CurrentLayer.Surface))
+            {
+                g.AppendPath(path);
 
-			return new Gdk.Rectangle (x, y, w, h);
-		}
+                double x1, y1, x2, y2;
+                cairo_path_extents(g.Handle, out x1, out y1, out x2, out y2);
+                rect = new Rectangle(x1, y1, x2 - x1, y2 - y1);
+            }
+
+            int x = (int)Math.Round(rect.X);
+            int y = (int)Math.Round(rect.Y);
+            int w = (int)Math.Round(rect.Width);
+            int h = (int)Math.Round(rect.Height);
+
+            return new Gdk.Rectangle(x, y, w, h);
+        }
 
 		public static Color Clone(this Color color)
 		{
@@ -1644,5 +1677,126 @@ namespace Pinta.Core
 
             return pattern;
         }
+
+        public static void BlendSurface (this Context g, Surface src, BlendMode mode = BlendMode.Normal, double opacity = 1.0)
+        {
+            g.Save ();
+            g.SetBlendMode (mode);
+            g.SetSourceSurface (src, 0, 0);
+            g.PaintWithAlpha (opacity);
+            g.Restore ();
+        }
+
+        public static void BlendSurface (this Context g, Surface src, Rectangle roi, BlendMode mode = BlendMode.Normal, double opacity = 1.0)
+        {
+            g.Save ();
+            g.Rectangle (roi);
+            g.Clip ();
+            g.SetBlendMode (mode);
+            g.SetSourceSurface (src, 0, 0);
+            g.PaintWithAlpha (opacity);
+            g.Restore ();
+        }
+
+        public static void BlendSurface (this Context g, Surface src, Point offset, BlendMode mode = BlendMode.Normal, double opacity = 1.0)
+        {
+            g.Save ();
+            g.Translate (offset.X, offset.Y);
+            g.SetBlendMode (mode);
+            g.SetSourceSurface (src, 0, 0);
+            g.PaintWithAlpha (opacity);
+            g.Restore ();
+        }
+
+        public static void SetBlendMode (this Context g, BlendMode mode)
+        {
+            switch (mode) {
+                case BlendMode.Normal:
+                    g.Operator = Operator.Over;
+                    break;
+                case BlendMode.Multiply:
+                    g.Operator = (Operator)ExtendedOperators.Multiply;
+                    break;
+                case BlendMode.ColorBurn:
+                    g.Operator = (Operator)ExtendedOperators.ColorBurn;
+                    break;
+                case BlendMode.ColorDodge:
+                    g.Operator = (Operator)ExtendedOperators.ColorDodge;
+                    break;
+                case BlendMode.HardLight:
+                    g.Operator = (Operator)ExtendedOperators.HardLight;
+                    break;
+                case BlendMode.SoftLight:
+                    g.Operator = (Operator)ExtendedOperators.SoftLight;
+                    break;
+                case BlendMode.Overlay:
+                    g.Operator = (Operator)ExtendedOperators.Overlay;
+                    break;
+                case BlendMode.Difference:
+                    g.Operator = (Operator)ExtendedOperators.Difference;
+                    break;
+                case BlendMode.Color:
+                    g.Operator = (Operator)ExtendedOperators.HslColor;
+                    break;
+                case BlendMode.Luminosity:
+                    g.Operator = (Operator)ExtendedOperators.HslLuminosity;
+                    break;
+                case BlendMode.Hue:
+                    g.Operator = (Operator)ExtendedOperators.HslHue;
+                    break;
+                case BlendMode.Saturation:
+                    g.Operator = (Operator)ExtendedOperators.HslSaturation;
+                    break;
+                case BlendMode.Lighten:
+                    g.Operator = (Operator)ExtendedOperators.Lighten;
+                    break;
+                case BlendMode.Darken:
+                    g.Operator = (Operator)ExtendedOperators.Darken;
+                    break;
+                case BlendMode.Screen:
+                    g.Operator = (Operator)ExtendedOperators.Screen;
+                    break;
+                case BlendMode.Xor:
+                    g.Operator = Operator.Xor;
+                    break;
+            }
+        }
+
+        public enum ExtendedOperators
+        {
+            Clear = 0,
+
+            Source = 1,
+            SourceOver = 2,
+            SourceIn = 3,
+            SourceOut = 4,
+            SourceAtop = 5,
+
+            Destination = 6,
+            DestinationOver = 7,
+            DestinationIn = 8,
+            DestinationOut = 9,
+            DestinationAtop = 10,
+
+            Xor = 11,
+            Add = 12,
+            Saturate = 13,
+
+            Multiply = 14,
+            Screen = 15,
+            Overlay = 16,
+            Darken = 17,
+            Lighten = 18,
+            ColorDodge = 19,
+            ColorBurn = 20,
+            HardLight = 21,
+            SoftLight = 22,
+            Difference = 23,
+            Exclusion = 24,
+            HslHue = 25,
+            HslSaturation = 26,
+            HslColor = 27,
+            HslLuminosity = 28
+        }
 	}
 }
