@@ -62,11 +62,6 @@ namespace Pinta.Core
 		public int CurrentLayerIndex {
 			get { return PintaCore.Workspace.ActiveDocument.CurrentUserLayerIndex; }
 		}
-
-		public bool ShowSelection {
-			get { return PintaCore.Workspace.ActiveDocument.ShowSelection; }
-			set { PintaCore.Workspace.ActiveDocument.ShowSelection = value; }
-		}
 		
 		public bool ShowSelectionLayer {
 			get { return PintaCore.Workspace.ActiveDocument.ShowSelectionLayer; }
@@ -202,11 +197,6 @@ namespace Pinta.Core
 			PintaCore.Workspace.ActiveDocument.ResetSelectionPaths ();
 		}
 
-		public ImageSurface GetFlattenedImage ()
-		{
-			return PintaCore.Workspace.ActiveDocument.GetFlattenedImage ();
-		}
-		
 		public ImageSurface GetClippedLayer (int index)
 		{
 			return PintaCore.Workspace.ActiveDocument.GetClippedLayer (index);
