@@ -25,6 +25,7 @@
 // THE SOFTWARE.
 
 using System;
+using System.IO;
 using Pinta.Resources;
 
 namespace Pinta
@@ -40,5 +41,10 @@ namespace Pinta
 		{
 			return ResourceLoader.GetIcon (name, size);
 		}
-	}
+
+        public Stream GetResourceIconStream (string name)
+        {
+            return ResourceLoader.GetResourceIconStream (name);
+        }
+    }
 }
