@@ -37,8 +37,6 @@ namespace Pinta.Core
 	{
 		private int active_document_index = -1;
 		private int new_file_name = 1;
-
-		public event EventHandler SelectionChanged;
 		
 		public WorkspaceManager ()
 		{
@@ -46,11 +44,6 @@ namespace Pinta.Core
             SelectionHandler = new SelectionModeHandler ();
 		}
 
-		public void CallSelectionChanged(object sender, EventArgs e)
-		{
-			SelectionChanged(sender, e);
-		}
-
 		public int ActiveDocumentIndex {
 			get {
 				return active_document_index;
@@ -148,8 +141,6 @@ namespace Pinta.Core
 		{
 			if (PintaCore.Workspace.HasOpenDocuments)
 				ActiveWorkspace.Invalidate ();
-			else
-				OnCanvasInvalidated (new CanvasInvalidatedEventArgs ());
 		}
 		
 		public void Invalidate (Gdk.Rectangle rect)
@@ -175,7 +166,11 @@ namespace Pinta.Core
 			doc.Workspace.History.PushNewItem (new BaseHistoryItem (Stock.New, Catalog.GetString ("New Image")));
 			doc.IsDirty = false;
 
-			PintaCore.Actions.View.ZoomToWindow.Activate ();
+			// This ensures these are called after the window is done being created and sized.
+			// Without it, we sometimes try to zoom when the window has a size of (0, 0).
+			Gtk.Application.Invoke (delegate {
+				PintaCore.Actions.View.ZoomToWindow.Activate ();
+			});
 
 			return doc;
 		}
@@ -200,8 +195,13 @@ namespace Pinta.Core
 				PintaCore.Workspace.ActiveWorkspace.History.PushNewItem (new BaseHistoryItem (Stock.Open, Catalog.GetString ("Open Image")));
 				PintaCore.Workspace.ActiveDocument.IsDirty = false;
 				PintaCore.Workspace.ActiveDocument.HasFile = true;
-				PintaCore.Actions.View.ZoomToWindow.Activate ();
-				PintaCore.Workspace.Invalidate ();
+
+                // This ensures these are called after the window is done being created and sized.
+                // Without it, we sometimes try to zoom when the window has a size of (0, 0).
+                Gtk.Application.Invoke (delegate {
+				    PintaCore.Actions.View.ZoomToWindow.Activate ();
+				    PintaCore.Workspace.Invalidate ();
+                });
 
 				fileOpened = true;
 			} catch (UnauthorizedAccessException e) {
@@ -308,24 +308,18 @@ namespace Pinta.Core
 		{
 			if (ActiveDocumentChanged != null)
 				ActiveDocumentChanged (this, EventArgs.Empty);
+
+            OnSelectionChanged ();
 				
 			ResetTitle ();
 		}
-		
-		protected internal void OnCanvasInvalidated (CanvasInvalidatedEventArgs e)
-		{
-			if (CanvasInvalidated != null)
-				CanvasInvalidated (this, e);
-		}
-
-		public void OnCanvasSizeChanged ()
-		{
-			if (CanvasSizeChanged != null)
-				CanvasSizeChanged (this, EventArgs.Empty);
-		}
 
 		protected internal void OnDocumentCreated (DocumentEventArgs e)
 		{
+            e.Document.SelectionChanged += (sender, args) => {
+		        OnSelectionChanged ();
+		    };
+
 			if (DocumentCreated != null)
 				DocumentCreated (this, e);
 		}
@@ -341,9 +335,15 @@ namespace Pinta.Core
 			if (DocumentClosed != null)
 				DocumentClosed (this, e);
 		}
-		#endregion
 
-		private void ShowOpenFileErrorDialog (Window parent, string filename, string primaryText, string details)
+		private void OnSelectionChanged ()
+		{
+            if (SelectionChanged != null)
+                SelectionChanged.Invoke(this, EventArgs.Empty);
+        }
+#endregion
+
+        private void ShowOpenFileErrorDialog (Window parent, string filename, string primaryText, string details)
 		{
 			string markup = "<span weight=\"bold\" size=\"larger\">{0}</span>\n\n{1}";
 			string secondaryText = string.Format (Catalog.GetString ("Could not open file: {0}"), filename);
@@ -351,14 +351,13 @@ namespace Pinta.Core
 			PintaCore.Chrome.ShowErrorDialog(parent, message, details);
 		}
 
-		#region Public Events
+#region Public Events
 		public event EventHandler ActiveDocumentChanged;
-		public event EventHandler<CanvasInvalidatedEventArgs> CanvasInvalidated;
-		public event EventHandler CanvasSizeChanged;
 		public event EventHandler<DocumentEventArgs> DocumentCreated;
 		public event EventHandler<DocumentEventArgs> DocumentOpened;
 		public event EventHandler<DocumentEventArgs> DocumentClosed;
-		#endregion
+		public event EventHandler SelectionChanged;
+#endregion
 		
 	}
 }
