@@ -25,6 +25,7 @@
 // THE SOFTWARE.
 using System.Reflection;
 using System.Runtime.CompilerServices;
+using Pinta.Core;
 
 // Information about this assembly is defined by the following attributes. 
 // Change them to the values specific to your project.
@@ -42,7 +43,7 @@ using System.Runtime.CompilerServices;
 // The form "{Major}.{Minor}.*" will automatically update the build and revision,
 // and "{Major}.{Minor}.{Build}.*" will update just the revision.
 
-[assembly: AssemblyVersion("1.6.0.0")]
+[assembly: AssemblyVersion(PintaCore.ApplicationVersion)]
 
 // The following attributes are used to specify the signing key for the assembly, 
 // if desired. See the Mono documentation for more information about signing.
