@@ -52,7 +52,7 @@ namespace Pinta.Actions
 			int response = dialog.Run ();
 
 			if (response == (int)Gtk.ResponseType.Ok
-			    && dialog.AreLayerPropertiesUpdated) {
+				&& dialog.AreLayerPropertiesUpdated) {
 
 				var historyMessage = GetLayerPropertyUpdateMessage (
 						dialog.InitialLayerProperties,
@@ -72,10 +72,13 @@ namespace Pinta.Actions
 			} else {
 
 				var layer = PintaCore.Workspace.ActiveDocument.CurrentUserLayer;
+				var selectionLayer = PintaCore.Workspace.ActiveDocument.SelectionLayer;
 				var initial = dialog.InitialLayerProperties;
 				initial.SetProperties (layer);
+				if (selectionLayer != null)
+					initial.SetProperties (selectionLayer);
 
-				if (layer.Opacity != initial.Opacity)
+				if ((layer.Opacity != initial.Opacity) || (layer.BlendMode != initial.BlendMode) || (layer.Hidden != initial.Hidden)) 
 					PintaCore.Workspace.ActiveWorkspace.Invalidate ();
 			}
 
