@@ -66,7 +66,8 @@ namespace Pinta
 			action_handlers.Add (new RotateZoomLayerAction ());
 
 			// View
-			action_handlers.Add (new ToolBarToggledAction ());
+            action_handlers.Add (new ToolBarToggledAction ());
+            action_handlers.Add (new ImageTabsToggledAction ());
 
 			// Window
 			action_handlers.Add (new CloseAllDocumentsAction ());
@@ -133,14 +134,19 @@ namespace Pinta
 			PintaCore.Actions.Image.Rotate180.Sensitive = enable;
 			PintaCore.Actions.Image.RotateCCW.Sensitive = enable;
 			PintaCore.Actions.Image.RotateCW.Sensitive = enable;
+		    PintaCore.Actions.Image.Flatten.Sensitive = enable;
 
 			PintaCore.Actions.Layers.AddNewLayer.Sensitive = enable;
+			PintaCore.Actions.Layers.DeleteLayer.Sensitive = enable;
 			PintaCore.Actions.Layers.DuplicateLayer.Sensitive = enable;
+			PintaCore.Actions.Layers.MergeLayerDown.Sensitive = enable;
+			PintaCore.Actions.Layers.ImportFromFile.Sensitive = enable;
 			PintaCore.Actions.Layers.FlipHorizontal.Sensitive = enable;
 			PintaCore.Actions.Layers.FlipVertical.Sensitive = enable;
-			PintaCore.Actions.Layers.ImportFromFile.Sensitive = enable;
-			PintaCore.Actions.Layers.Properties.Sensitive = enable;
 			PintaCore.Actions.Layers.RotateZoom.Sensitive = enable;
+		    PintaCore.Actions.Layers.MoveLayerUp.Sensitive = enable;
+		    PintaCore.Actions.Layers.MoveLayerDown.Sensitive = enable;
+			PintaCore.Actions.Layers.Properties.Sensitive = enable;
 
 			PintaCore.Actions.Adjustments.ToggleActionsSensitive (enable);
 			PintaCore.Actions.Effects.ToggleActionsSensitive (enable);
